yakumo.glance.v1.image

Package yakumo :: Package glance :: Package v1 :: Module image |
[hide private]
[frames] | no frames]

# Module image

source code

Resource class and its manager for images in Image V1 API

Classes | [hide private]
| Resource resource class for images on Image V1 API
| Manager manager class for images on Image V1 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.glance.v1``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('disk_form
      at', 'disk_format', mapper.Noop), ('container_format', 'container_form
      at', mapper.Noop), ('size', 'size', mapper.Noop), ('virtual_size', 'vi
      rtual_size', mapper.Noop), ('checksum', 'checksum', mapper.Noop), ('mi
      n_ram', 'min_ram', mapper.Noop), ('min_disk', 'min_disk', mapper.Noop)
      , ('owner', 'owner', mapper.Noop), ('properties', 'properties', mapper
      .Noop), ('is_public', 'is_public', mapper.Noop), ('status', 'status',
      mapper.Noop), ('created_at', 'created_at', mapper.DateTime), ('updated
      ...